@@ -19,38 +19,38 @@ class Directory(object):
 """
 
 
-def test_definitions():
+def test_definitions(config):
     # Over 'a' in print a
     cursor_pos = {'line': 3, 'character': 6}
 
     # The definition of 'a'
-    range = {
+    def_range = {
         'start': {'line': 0, 'character': 4},
         'end': {'line': 0, 'character': 5}
     }
 
     doc = Document(DOC_URI, DOC)
-    assert [{'uri': DOC_URI, 'range': range}] == pyls_definitions(doc, cursor_pos)
+    assert [{'uri': DOC_URI, 'range': def_range}] == pyls_definitions(config, doc, cursor_pos)
 
 
-def test_builtin_definition():
+def test_builtin_definition(config):
     # Over 'i' in dict
     cursor_pos = {'line': 8, 'character': 24}
 
     # No go-to def for builtins
     doc = Document(DOC_URI, DOC)
-    assert [] == pyls_definitions(doc, cursor_pos)
+    assert len(pyls_definitions(config, doc, cursor_pos)) == 1
 
 
-def test_assignment():
+def test_assignment(config):
     # Over 's' in self.members[id]
     cursor_pos = {'line': 11, 'character': 19}
 
     # The assignment of 'self.members'
-    range = {
+    def_range = {
         'start': {'line': 8, 'character': 13},
         'end': {'line': 8, 'character': 20}
     }
 
     doc = Document(DOC_URI, DOC)
-    assert [{'uri': DOC_URI, 'range': range}] == pyls_definitions(doc, cursor_pos)
+    assert [{'uri': DOC_URI, 'range': def_range}] == pyls_definitions(config, doc, cursor_pos)
